@@ -16,7 +16,7 @@ void Counting_Type_of_Transitions( double ** Presence, int S,
 	  else if (Presence[i][j-1] == 1.0 && Presence[i][j] == 0.0) { n01++; }
 	  else if (Presence[i][j-1] == 1.0 && Presence[i][j] == 1.0) { n11++; }
 	  // else    { Rprintf(" Error in Counting_Type_of_Transitions(...). Program will abort!!!\n"); exit(1); }
-	  else    { Rprintf(" Error in Counting_Type_of_Transitions(...)\n"); error(0,0,"Program aborted"); }
+	  else    { Rprintf(" Error in Counting_Type_of_Transitions(...)\n"); error("Program aborted"); }
 	}
       }
 
