@@ -28,7 +28,7 @@ double GSL_NLL_Function_Uneven( const gsl_vector * x, void * Par )
   F->P->Time          = &Time;
   if( F->P->No_of_SPECIES != F->Data->No_of_SPECIES )
     //error(0,0,"Number of Species does not match: program aborted");
-    { Rprintf("Number of Species does not match: "); error(0,0,"Program aborted"); }
+    { Rprintf("Number of Species does not match: "); error("Program aborted"); }
 
   int No_of_SPECIES        = F->P->No_of_SPECIES;
   double Colonization_Rate = gsl_vector_get( x, 0 );
