@@ -15,7 +15,7 @@ double GSL_NLLikelihood_Function ( const gsl_vector * x, void * Par )
 
   if( F->P->No_of_SPECIES != F->Data->No_of_SPECIES )
     // error(0,0,"Number of Species does not match: program aborted");
-    { Rprintf("Number of Species does not match: "); error(0,0,"Program aborted"); }
+    { Rprintf("Number of Species does not match: "); error("Program aborted"); }
 
   Time_Control * T    = F->P->Time;
   int No_of_SPECIES   = F->P->No_of_SPECIES;
@@ -116,7 +116,7 @@ double NLLikelihood_Calculation ( int n, Time_Control * Time,
 	  Rprintf(" (see GSL_NLLikelihood_Function.c)\n");
 	  Rprintf(" The program will exit\n");
 	  // error(0, 0, "Program has aborted");
-	  Rprintf("Program has aborted: "); error(0,0,"in NLLikelihood_Calculation");
+	  Rprintf("Program has aborted: "); error("in NLLikelihood_Calculation");
 #endif
 	}
         NLL += X;
@@ -191,13 +191,13 @@ double NLLikelihood_Calculation_Transition_Probabilities ( int n, Time_Control *
 	else {
 	  if( P_k_1 != 0.1 )
 	    // error(0,0,"Missing Value Problem: program aborted");
-	    { Rprintf("Missing Value Problem: "); error(0,0,"Program aborted"); }
+	    { Rprintf("Missing Value Problem: "); error("Program aborted"); }
 	}
       }
       else {
 	  if( P_k_0 != 0.1 )
 	    // error(0,0,"Missing Value Problem: program aborted");
-	    { Rprintf("Missing Value Problem: "); error(0,0,"Program aborted"); }
+	    { Rprintf("Missing Value Problem: "); error("Program aborted"); }
       }
     }
   }
