@@ -253,7 +253,7 @@ void MODEL_SELECTION_UPGMA_MacKENZIE_R_SHLIB(double Colonization_Rate, double *
 	  m++;
 	}
       }
-      if( R[i][j] != m ) { Rprintf("Program aborted\n"); error(0,0,"Program aborted"); }
+      if( R[i][j] != m ) { Rprintf("Program aborted\n"); error("Program aborted"); }
     }
     if( (*Verbose) == 1) Rprintf("\n");
     /*     E N D : --------------------------------------------------------
@@ -282,7 +282,7 @@ void MODEL_SELECTION_UPGMA_MacKENZIE_R_SHLIB(double Colonization_Rate, double *
 	}
 
       }
-      if( R[i][j] != m ) { Rprintf("Program aborted\n"); error(0,0,"Program aborted"); } // assert( R[i][j] == m );
+      if( R[i][j] != m ) { Rprintf("Program aborted\n"); error("Program aborted"); } // assert( R[i][j] == m );
 
       if( (*Verbose) == 1) Rprintf("\n");
       m = 0;
@@ -302,7 +302,7 @@ void MODEL_SELECTION_UPGMA_MacKENZIE_R_SHLIB(double Colonization_Rate, double *
 	  m++;
 	}
       }
-      if( R[i][j] != m ) { Rprintf("Program aborted\n"); error(0,0,"Program aborted"); } // assert( R[i][j] == m );
+      if( R[i][j] != m ) { Rprintf("Program aborted\n"); error("Program aborted"); } // assert( R[i][j] == m );
       // if( (*Verbose) == 1 )  getchar();
     }
     /*     E N D : ---------------------------------------------------------*/
