@@ -65,7 +65,7 @@ void MODEL_SELECTION_UPGMA_R_FUNCTION( int * pNo_of_SPECIES, char ** Species_Tag
   int No_of_COLUMNS;
   No_of_COLUMNS = No_of_TIMES[0];
   for ( i=0; i<No_of_SPECIES; i++ )
-    if ( No_of_COLUMNS != No_of_TIMES[i] ) { Rprintf("Program aborted\n"); error(0,0,"Program aborted"); }
+    if ( No_of_COLUMNS != No_of_TIMES[i] ) { Rprintf("Program aborted\n"); error("Program aborted"); }
   Rprintf( "Number of Columns: %d\n", No_of_COLUMNS );
 
   n=0;
@@ -160,7 +160,7 @@ void MODEL_SELECTION_UPGMA_DRIVER ( int No_of_SPECIES, char ** Species_Tag,
   /* Warning: No_of_COLUMNS for all data files should match!!!  */
   int No_of_COLUMNS = No_of_TIMES[0];
   for(i=0; i<No_of_SPECIES; i++) if( No_of_COLUMNS != No_of_TIMES[i] )
-				   { Rprintf("Program aborted\n"); error(0,0,"Program aborted"); }
+				   { Rprintf("Program aborted\n"); error("Program aborted"); }
 
   int * Dummy;
   //No use in this context. It could handle different replicates (transects)
