@@ -10,7 +10,7 @@ void program_exit_for_matrix_corruption(int Sp, int Presence, int Time)
   Rprintf("Species: %d\t State: %d\t Time: %d\n", Sp, Presence, Time);
   Rprintf("State can only be either 0 or 1\n");
   Rprintf("The program will exit\n");
-  Rprintf("Program aborted...");  error(0,0,"Program aborted");
+  Rprintf("Program aborted...");  error("Program aborted");
 
 }
 
@@ -27,7 +27,7 @@ int Determining_Total_No_of_Absences (double * Presence_Data, int N,
       if ( j >= N ) Rprintf(" j = %d\t N = %d\n", j, N);
       if( j >= N )
 	// error(0,0, "Program aborted");
-	{ Rprintf("Program will abort..."); error(0,0,"Program aborted"); }
+	{ Rprintf("Program will abort..."); error("Program aborted"); }
       if (Presence_Data[j] == 0.0) m++;
     }
     if( m == Transects[i] ) Time_Index[k++] = i;
@@ -128,7 +128,7 @@ double MacKenzie_NLLikelihood_Calculation ( double ** Presence_Data, int No_of_S
           for(n=0; n<Transects[0]; n++) if (Presence_Data[j][n] == 0.0) m++;
           if (m != Transects[0])
           //error(0,0,"Number of Transects does not match");
-          { Rprintf("Number of Transects does not match"); error(0,0,"Program aborted"); }
+          { Rprintf("Number of Transects does not match"); error("Program aborted"); }
 
           Y += logl( 1.0 - (long double)Phi_0 );
         }
@@ -159,10 +159,10 @@ double MacKenzie_NLLikelihood_Calculation ( double ** Presence_Data, int No_of_S
           /* Transiction: k_0 ---> k_1 */
           k_0 = Presence[i-1];    if( k_0 != 0 && k_0 != 1 )
 				    // error(0,0,"Program aborted");
-				    { Rprintf("Program will abort...");  error(0,0,"Program aborted"); }
+				    { Rprintf("Program will abort...");  error("Program aborted"); }
             k_1 = Presence[i];      if( k_1 != 0 && k_1 != 1 )
 				    // error(0,0,"Program aborted");
-				    { Rprintf("Program will abort...");  error(0,0,"Program aborted"); }
+				    { Rprintf("Program will abort...");  error("Program aborted"); }
 
             Y += logl( (long double)TM[k_1][k_0] ) ;
 
@@ -172,7 +172,7 @@ double MacKenzie_NLLikelihood_Calculation ( double ** Presence_Data, int No_of_S
               for(n = n_0; n<(n_0+Transects[i]); n++) if (Presence_Data[j][n] == 0.0) m++;
               if ( m != Transects[i] )
               // error(0,0,"Number of Transects do not match");
-              { Rprintf("Number of Transects do not match"); error(0,0,"Program aborted"); }
+              { Rprintf("Number of Transects do not match"); error("Program aborted"); }
             }
             else if (Presence[i] == 1) {
               m = 0;
@@ -184,7 +184,7 @@ double MacKenzie_NLLikelihood_Calculation ( double ** Presence_Data, int No_of_S
 
               if(Transects[i] < m)
               // error(0,0, "Program aborted");
-              { Rprintf("Program will abort...");  error(0,0,"Program aborted"); }
+              { Rprintf("Program will abort...");  error("Program aborted"); }
               //X += log(Combinarory(m, Transects[0]));
             }
             else {
@@ -196,7 +196,7 @@ double MacKenzie_NLLikelihood_Calculation ( double ** Presence_Data, int No_of_S
             n_0 += Transects[i];
             if( i == (T-1) ) if( n_0 != N )
             // error(0,0, "Program aborted");
-            { Rprintf("Program will abort...");  error(0,0,"Program aborted"); }
+            { Rprintf("Program will abort...");  error("Program aborted"); }
         }
         free(Presence);
 
@@ -205,7 +205,7 @@ double MacKenzie_NLLikelihood_Calculation ( double ** Presence_Data, int No_of_S
 
         if( Y >= 0.0 )
         // error(0,0, "Program aborted");
-        { Rprintf("Program will abort...");  error(0,0,"Program aborted"); }
+        { Rprintf("Program will abort...");  error("Program aborted"); }
       }
 
       free(Time_Index);
