@@ -69,7 +69,7 @@ void mle_Col_Ext_Uneven_Matrix_R_SHLIB (double ** Presence, int S,
 
   if( (* No_of_PARAMETERS_MAX) != (* No_of_PARAMETERS) )
 	// error(0,0,"Number of Parameters do not match");
-	{ Rprintf("Number of Parameters do not match"); error(0,0,"Program aborted"); }
+	{ Rprintf("Number of Parameters do not match"); error("Program aborted"); }
 
   // int No_C, No_E, No_D, No_P;
   // Parameter_Index_Checking_Ordering(Index, Discretization, (* No_of_PARAMETERS_MAX),
